summaryrefslogtreecommitdiff
path: root/audio/sysvad/EndpointsCommon/mintopo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'audio/sysvad/EndpointsCommon/mintopo.cpp')
-rw-r--r--audio/sysvad/EndpointsCommon/mintopo.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/audio/sysvad/EndpointsCommon/mintopo.cpp b/audio/sysvad/EndpointsCommon/mintopo.cpp
index 128fa15c..28ddf419 100644
--- a/audio/sysvad/EndpointsCommon/mintopo.cpp
+++ b/audio/sysvad/EndpointsCommon/mintopo.cpp
@@ -110,13 +110,13 @@ Return Value:
DPF_ENTER(("[CMiniportTopology::~CMiniportTopology]"));
-#if defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND)
+#if defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND) || defined (SYSVAD_A2DP_SIDEBAND)
if (IsSidebandDevice())
{
ASSERT(m_pSidebandDevice != NULL);
//
// Register with BthHfpDevice or UsbHsDevice to get notification events.
//
if(IsSidebandDevice())
{
@@ -127,7 +127,7 @@ Return Value:
SAFE_RELEASE(m_pSidebandDevice); // ISidebandDeviceCommon
}
-#endif // defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND)
+#endif // defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND) || defined(SYSVAD_A2DP_SIDEBAND)
} // ~CMiniportTopology
@@ -281,7 +281,7 @@ Return Value:
DPF(D_ERROR, ("Init: CMiniportTopologySYSVAD::Init failed, 0x%x", ntStatus)),
Done);
-#if defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND)
+#if defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND) || defined(SYSVAD_A2DP_SIDEBAND)
if (IsSidebandDevice())
{
PSIDEBANDDEVICECOMMON sidebandDevice = NULL;
@@ -306,7 +306,7 @@ Return Value:
}
else
{
- ASSERT(m_DeviceType == eBthHfpSpeakerDevice || m_DeviceType == eUsbHsSpeakerDevice);
+ ASSERT(m_DeviceType == eBthHfpSpeakerDevice || m_DeviceType == eUsbHsSpeakerDevice || m_DeviceType == eA2dpHpSpeakerDevice);
sidebandDevice->SetVolumeHandler(
m_DeviceType,
@@ -319,7 +319,7 @@ Return Value:
PCMiniportTopology(this)); // context.
}
}
-#endif // defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND)
+#endif // defined(SYSVAD_BTH_BYPASS) || defined(SYSVAD_USB_SIDEBAND) || defined(SYSVAD_A2DP_SIDEBAND)
Done:
return ntStatus;
@@ -110,13 +110,13 @@ Return Value:
ASSERT(m_pSidebandDevice != NULL);
//
- // Register with BthHfpDevice or UsbHsDevice to get notification events.
+ // Register with BthHfpDevice, A2dpHpDevice or UsbHsDevice to get notification events.
//
if(IsSidebandDevice())